@@ -4,7 +4,7 @@ import itertools
 import pytest
 
 from nextline.state import Initialized, StateObsoleteError, StateMethodError
-from nextline.utils import Registry
+from nextline.utils import SubscribableDict
 
 SOURCE_ONE = """
 import time
@@ -24,13 +24,9 @@ class BaseTestState(ABC):
 
     @pytest.fixture()
     def registry(self, statement):
-        y = Registry()
-        # y.open_register("statement")
-        # y.open_register("state_name")
-        # y.open_register("run_no")
-        # y.open_register("run_no_count")
-        y.register("statement", statement)
-        y.register("run_no_count", itertools.count().__next__)
+        y = SubscribableDict()
+        y["statement"] = statement
+        y["run_no_count"] = itertools.count().__next__
         yield y
         y.close()
 
