@@ -5,7 +5,7 @@ from typing import Set
 
 from nextline.trace import Trace
 from nextline.pdb.proxy import PdbInterfaceFactory, PdbInterface
-from nextline.utils import Registry
+from nextline.utils import SubscribableDict
 from nextline.registry import PdbCIRegistry
 
 from .funcs import TraceSummary
@@ -43,7 +43,7 @@ def thread():
 @pytest.fixture()
 def target_trace_func(modules_to_trace: Set[str]):
     y = Trace(
-        registry=Mock(spec=Registry),
+        registry=Mock(spec=SubscribableDict),
         pdb_ci_registry=Mock(spec=PdbCIRegistry),
         modules_to_trace=modules_to_trace,
     )
